# Artap - robust design optimization

Artap is a framework for robust design optimization in Python. 
It provides tools for coupling FEM solvers (Agros2D, Comsol) with metaheuristic, bayesian or neural network based
optimization algorithms.

## Installation

### Linux
```
pip3 install artap
```

## Examples